@@ -52,33 +52,36 @@ getNEDSpectra(hosts, hSpecPath, verbose) #get spectra of hosts
 getTNSSpectra(transients, tSpecPath, verbose) #get spectra of transients (if on TNS)
 
 
-####################### helper functions for querying the database #############
-
-# Get cooordinates associated with NGC 4568
+# Helper functions for querying the database
 supernovaCoord = [SkyCoord(344.5011708333333*u.deg, 6.0634388888888875*u.deg, frame='icrs')]
-table = fullData()
-
 galaxyCoord = [SkyCoord(344.50184181*u.deg, 6.06983149*u.deg, frame='icrs')]
 snName = ["PTF10llv"]
+table = fullData()
 
-db, notFound = getDBHostFromTransientCoords(supernovaCoord)
-db, notFound = getDBHostFromTransientName(snName)
+# 1. Get the entry corresponding to a specific transient by its name (or coordinates)
+#    note: The coordinate/name is passed as a list, so multiple entries can be
+#          queried simultaneously
+#    This function returns the matches as a pandas dataframe (df) along with
+#    a list of the sources not found (by name or coordinate)
+df, notFound = getDBHostFromTransientCoords(supernovaCoord)
+df, notFound = getDBHostFromTransientName(snName)
 
-snName = ["SN2017hpi"]
+# 2. Print summary statistics about a particular host galaxy system or set of systems from a supernova
 getHostStatsFromTransientName(snName)
 getHostStatsFromTransientCoords(supernovaCoord)
 
+# 3. Get stats about the supernovae associated with a host galaxy
 galaxyName = ['UGC 12266']
-getTransientStatsFromHostName()
+getTransientStatsFromHostName(galaxyName)
 getTransientStatsFromHostCoords(galaxyCoord)
 
-getcolorim(ra, dec, size=tempSize, filters=band, format="png")
-getHostImage('PTF10llv', save=0)
+# 4. get an image of the field by coordinates
+tempSize = 400 #size in pixels
+band = ['grizy']
+getcolorim(galaxyCoord[0].ra.deg, galaxyCoord[0].dec.deg, size=tempSize, filters=band, format="png")
 
-path = "/home/alexgagliano/Documents/Research/Transient_ML/tables/SNspectra/"
-hostPath = '/home/alexgagliano/Documents/Research/Transient_ML_Box/hostSpectra/'
+# 5. get an image of the host galaxy system associated with a supernova (by supernova name)
+getHostImage(snName, save=0)
 
-getTransientSpectra('SN2019ur', path)
-getHostSpectra('2019dfi', hostPath)
-
-coneSearchPairs(supernovaCoord, 1.e5)
+# 6. Find all supernova-host galaxy matches within a certain search radius (in arcseconds)
+coneSearchPairs(supernovaCoord[0], 1.e3)
